You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ph...@apache.org on 2010/03/09 13:35:18 UTC

svn commit: r920845 - in /subversion/trunk/subversion/libsvn_client: client.h commit_util.c

Author: philip
Date: Tue Mar  9 12:35:18 2010
New Revision: 920845

URL: http://svn.apache.org/viewvc?rev=920845&view=rev
Log:
* subversion/libsvn_client/client.h
  (svn_client__copy_pair_t, svn_client__harvest_committables): Tweak doc string.

* subversion/libsvn_client/commit_util.c
  (harvest_committables): Tweak doc string.

Modified:
    subversion/trunk/subversion/libsvn_client/client.h
    subversion/trunk/subversion/libsvn_client/commit_util.c

Modified: subversion/trunk/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/client.h?rev=920845&r1=920844&r2=920845&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/client.h (original)
+++ subversion/trunk/subversion/libsvn_client/client.h Tue Mar  9 12:35:18 2010
@@ -756,7 +756,7 @@ typedef struct
     /* The absolute destination path or url */
     const char *dst;
 
-    /* The absolute destination's parent path */
+    /* The absolute source path or url of the destination's parent. */
     const char *dst_parent_abspath;
 } svn_client__copy_pair_t;
 
@@ -818,7 +818,7 @@ typedef struct
 #define SVN_CLIENT__SINGLE_REPOS_NAME "svn:single-repos"
 
 
-/* Recursively crawl a set of working copy paths (PARENT_DIR + each
+/* Recursively crawl a set of working copy paths (DIR_ABSPATH + each
    item in the TARGETS array) looking for commit candidates, locking
    working copy directories as the crawl progresses.  For each
    candidate found:

Modified: subversion/trunk/subversion/libsvn_client/commit_util.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit_util.c?rev=920845&r1=920844&r2=920845&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/commit_util.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit_util.c Tue Mar  9 12:35:18 2010
@@ -326,15 +326,15 @@ bail_on_tree_conflicted_ancestor(svn_wc_
 }
 
 
-/* Recursively search for commit candidates in (and under) PATH (with
-   entry ENTRY and ancestry URL), and add those candidates to
+/* Recursively search for commit candidates in (and under) LOCAL_ABSPATH
+   (with entry ENTRY and ancestry URL), and add those candidates to
    COMMITTABLES.  If in ADDS_ONLY modes, only new additions are
    recognized.  COPYFROM_URL is the default copyfrom-url for children
    of copied directories.
 
-   DEPTH indicates how to treat files and subdirectories of PATH when
-   PATH is itself a directory; see svn_client__harvest_committables()
-   for its behavior.
+   DEPTH indicates how to treat files and subdirectories of LOCAL_ABSPATH
+   when LOCAL_ABSPATH is itself a directory; see
+   svn_client__harvest_committables() for its behavior.
 
    Lock tokens of candidates will be added to LOCK_TOKENS, if
    non-NULL.  JUST_LOCKED indicates whether to treat non-modified items with